 *======================= PROGRAM: PQI09_ALL_CONTROL.SAS ======================== ;
 *  VERSION: AHRQ QI v7.0.1 BETA
 *  RELEASE DATE: DECEMBER 2017
 * ============================================================================== ;
 * The PREVENTION QUALITY INDICATOR PQI 09 STAND ALONE module of the AHRQ 
   Indicators software includes the following programs:
   
   1. PQI09_ALL_CONTROL.SAS    Assigns user inputs required by other programs
                         and optional output options. 
                  
   2. PQI09_ALL_FORMATS.SAS    Creates SAS format library used by other programs.

   3. PQI09_ALL_MEASURES.SAS   Assigns numerator flags for Prevention Quality Indicators. 

   4. PQI09_AREA_OBSERVED.SAS  Calculates observed rates for area indicators.

 * The software also requires the following files:
 
   1. discharges.sas7bdat  User supplied discharge level file organized according 
                           to the layout in the software instructions.
                           The file name is up to the user but must be listed below.
                     
   2. PQI09_Dx_Px_Macros.SAS  Standard processes used by the other SAS programs.
                              The user does not need to open.
                     
    3. pop95t17.txt           Population file with counts by area, age, and sex.
                              Required for area rate calculation. Available as separate
                              download from AHRQ website.

 NOTE THAT THIS INDICATOR (PQI 09) IS ALSO INCLUDED IN THE PDI MODULE.

***************************************************************************** ;
******************************* PLEASE READ ********************************* ;
***************************************************************************** ;
 * The AHRQ Quality Indicator software is intended for use with discharges
   coded according to the standards in place at the date of the discharge. 
   Discharges should be classified under the ICD-10-CM/PCS specifications 
   effective 10/1/2015. All diagnosis codes require a corresponding Present
   on admission, POA, value coded according to UB04 standards. 
   Although results can be generated with inputs coded under ICD9 and 
   converted to ICD10 with General Equivalence Mappings, the mapping process
   may produce unrepresentative results. ICD10 observed rate calculations
   should not be used to produce ICD9 risk adjusted outputs.
   
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software are changes in this program (PQI09_ALL_CONTROL.SAS). 
   The modifications include such items as specifying the name and location
   of the input data set, the year of population data to be used, and the 
   name and location of output data sets.
 
 * NOTE:  PQI09_ALL_CONTROL.SAS provides the option to read data in and write 
          data out to different locations.  For example, "libname INMSR" points
        to the location of the input data set for the PQI09_ALL_MEASURES.SAS
        program and "libname OUTMSR" points to the location of the output data
        set created by the PQI09_ALL_MEASURES.SAS program.  The location and 
        file name of each input and output can be assigned separately below.  
        The default values will place output in a SASData folder with standard 
        names for each file based on the location of the PQI09 folder listed  
        in the PATHNAME variable.
        
 * NOTE:  In the other programs included with this package there is a 
        line of code that begins with "filename CONTROL".  
        The USER MUST include after "filename CONTROL" the location
        of the PQI09_ALL_CONTROL.SAS file.

 Generally speaking, a first-time user of this software would proceed 
 as outlined below:

    1.  Modify and save PQI09_ALL_CONTROL.SAS. (This program - MUST be done.)
    2.  Open PQI09_ALL_FORMATS.SAS and specify location (pathname) of
        PQI09_ALL_CONTROL.SAS. (MUST be done.)
    3.  Run PQI09_ALL_FORMATS.SAS. (MUST be done.) 
    4.  Open PQI09_ALL_MEASURES.SAS and specify location of PQI09_ALL_CONTROL.SAS
      program. (MUST be done.)
    5.  Run PQI09_ALL_MEASURES.SAS. (MUST be done.)
    6.  To calculate observed rates for Area level Prevention  
      Quality Indicators:
         a.  Open PQI09_AREA_OBSERVED.SAS and specify location
             of PQI09_ALL_CONTROL.SAS program. (MUST be done.) 
         b.  Run PQI09_AREA_OBSERVED.SAS. (MUST have run PQI09_ALL_MEASURES.SAS.)

 * ---------------------------------------------------------------- ;
 * ---                 INPUTS FOR ALL PROGRAMS                  --- ;
 * ---------------------------------------------------------------- ;

*PATHNAME specifies the location of the PQI09 folder which includes the
          Programs, Macros, and SASdata subfolders;
%LET PATHNAME=C:\pathname\PQI09;                     *<===USER MUST modify;
*DISFOLDER specifies the folder that contains the discharge data;
%LET DISFOLDER=c:\pathname;       *<===USER MUST modify;
*DISCHARGE specifies the name of the discharge data file;
%LET DISCHARGE=discharges;              *<===USER MUST modify;
*SUFX specifies an identifier suffix to be placed on output datasets;
%LET SUFX = v7_ICD10;                           *<===USER may modify;

*LIBRARY is where formats generated by PQI09_ALL_FORMATS will be saved.;    
LIBNAME LIBRARY  "&PATHNAME.\SASData";                    *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF COUNTY-LEVEL AREAS SHOULD BE CONVERTED TO MAs -- ;
 * ---     0 - County level with U.S. Census FIPS                -- ;
 * ---     1 - County level with Modified FIPS                   -- ;
 * ---     2 - Metro Area level with OMB 1999 definition         -- ;
 * ---     3 - Metro Area level with OMB 2003 definition         -- ;
 * ---------------------------------------------------------------- ;
%LET MALEVL = 0;                                *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * NOTE:  SELECT THE YEAR IN THE POPULATION FILE THAT BEST MATCHES  ;
 *        THE DISCHARGE DATA. POPYEAR WILL IDENTIFY POPULATION USED ;
 *        BY THE PQI09_AREA_OBSERVED.SAS PROGRAM.                   ;
 * ---------------------------------------------------------------- ;
%LET POPYEAR = 2017;                           *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF POPULATION FILE                          --- ;
 * ---------------------------------------------------------------- ;
filename POPFILE  "&PATHNAME.\pop95t17.txt";  *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED IN SAS OUTPUT AT   --- ;
 * --- END OF EACH PROGRAM.  0 = NO, 1 = YES                    --- ;
 * ---------------------------------------------------------------- ;
%LET PRINT = 0;                                *<===USER may modify.;
  * --------------------------------------------------------------- ;
 * --- ADD OPTIONS TO COMPRESS OUTPUT AND SUPPRESS SOURCE CODE  --- ;
 * --- IN LOG. RECOMMENDED WITH LARGE FILES. TO RESTORE, RUN:   --- ;
 * --- options source compress = no                             --- ;
 * ---------------------------------------------------------------- ;
options compress = YES ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF SAS MACRO LIBRARY                        --- ;
 * ---------------------------------------------------------------- ;
filename MacLib "&PATHNAME.\Macros\" ;         *<===USER may modify.;
 * ---------------------------------------------------------------- ;
 * ---            PROGRAM: PQI09_ALL_MEASURES.SAS               --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PQI09_ALL_MEASURES.SAS INPUT DATA        --- ;
 * ---------------------------------------------------------------- ;
libname INMSR  "&DISFOLDER.";                   *<==USER may modify; 
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PQI09_ALL_MEASURES.SAS OUTPUT DATA       --- ;
 * ---------------------------------------------------------------- ;
libname OUTMSR "&PATHNAME.\SASdata";             *<==USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET NAME OF OUTPUT FILE FROM PQI09_ALL_MEASURES.SAS      --- ;
%LET OUTFILE_MEAS = PQ9MSR_&SUFX.; *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                             --- ;
 * ---------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                        --- ;
 * ---     35 DIAGNOSES (DX1-DX35)                              --- ;
 * ---------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSIS VARIABLES TO                  --- ;
 * --- MATCH USER DISCHARGE INPUT DATA                          --- ;
 * ---------------------------------------------------------------- ;
%LET NDX = 35;                                   *<===USER may modify;

* ----------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL    --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE       --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER --- ;
 * - RUNNING PQI09_ALL_MEASURES.SAS.                        --- ;
 * ---------------------------------------------------------------- ;
%LET DELFILE  = PQI09_DELETED_&SUFX.;           *<===USER may modify;

* ==================================================================;
* =========== AREA-LEVEL PREVENTION QUALITY INDICATORS =============;
* ==================================================================;
* ---          PROGRAM INPUTS: PQI09_AREA_OBSERVED.SAS         ---- ;
* ----------------------------------------------------------------- ;
libname OUTAOBS "&PATHNAME.\SASdata";     *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- TYPELVLA indicates the levels (or _TYPE_) of             --- ;
 * --- summarization to be kept in the output.                  --- ;
 * ---                                                          --- ;
 * ---  TYPELVLA      stratification                            --- ;
 * ---  --------  -------------------------                     --- ;
 * ---     0      overall                                       --- ;
 * ---     1                           race                     --- ;
 * ---     2                     sex                            --- ;
 * ---     3                     sex * race                     --- ;
 * ---     4               age                                  --- ;
 * ---     5               age *       race                     --- ;
 * ---     6               age * sex                            --- ;
 * ---     7               age * sex * race                     --- ;
 * ---     8       area                                         --- ;
 * ---     9       area  *             race                     --- ;
 * ---    10       area  *       sex                            --- ;
 * ---    11       area  *       sex * race                     --- ;
 * ---    12       area  * age                                  --- ;
 * ---    13       area  * age *       race                     --- ;
 * ---    14       area  * age * sex                            --- ;
 * ---    15       area  * age * sex * race                     --- ;
 * ---                                                          --- ;
 * --- The default TYPELVLA (0,8) will provide an overall       --- :
 * --- total and an area-level total.                           --- ;
 * ---                                                          --- ;
 * ---------------------------------------------------------------- ;
%LET TYPELVLA = IN (0,8);             *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- NAME OF SAS DATASET OUTPUT FROM  PQI09_AREA_OBSERVED.SAS  --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED AREA RATES.               --- ;
 * ----------------------------------------------------------------- ;
%LET  OUTFILE_AREAOBS = PQ9AO_&SUFX.;     *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR--- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.               --- ;
 * ----------------------------------------------------------------- ;
%LET TXTAOBS=0;                                  *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION -- ;
 * --- OF THE FILE.                                              --- ;
 * ----------------------------------------------------------------- ;
filename P9TXTAO "&PATHNAME.\SASdata\PQ9AO_&SUFX..TXT";  *<===USER may modify;

************************* END USER INPUT ************************** ;  
