*================== PROGRAM: PSI17_ALL_FORMATS.SAS ======================== ;
*
*  DESCRIPTION:
*     FORMAT LIBRARY FOR STAND ALONE AHRQ PATIENT SAFETY INDICATOR 17.
*     NOTE THAT PATIENT SAFETY INDICATOR PSI 17 IS INCLUDED IN THE PEDIATRIC
*     QUALITY INDICATOR MODULE (PDI).
*
*  VERSION: AHRQ QI v7.0.1 BETA
*  RELEASE DATE: DECEMBER 2017
*
*========================================================================= ;
*PATHNAME specifies the location of the PSI17 folder which includes the
Programs, Macros, and SASdata subfolders;
%LET PATHNAME=C:\PATHNAME\PSI17;              *<==USER MUST modify;
 
filename CONTROL "&PATHNAME.\Programs\PSI17_ALL_CONTROL.SAS";
 
%INCLUDE CONTROL;
 
 
proc format library=LIBRARY;
 
/* -------------------------------------------------------------- */
/* --- FORMATS FOR STRATIFIERS ---------------------------------- */
/* -------------------------------------------------------------- */
 
/* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
1 = 'Male'
2 = 'Female'
;
 
/* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value PAGECAT
1 = "<1"
2 = "1 TO 2"
3 = "3 TO 5"
4 = "6 TO 12"
5 = "13 TO 17"
;
 
/* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
value AGEDCAT
0 = "NA"
1 = "0 TO 28"
2 = "29 TO 60"
3 = "61 TO 90"
4 = "91+"
;
 
/* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
value BWHTCAT
0 = "NA"
1 = "0 TO 499g"
2 = "500 TO 749g"
3 = "750 TO 999g"
4 = "1000 TO 1249g"
5 = "1250 TO 1499g"
6 = "1500 TO 1749g"
7 = "1750 TO 1999g"
8 = "2000 TO 2499g"
9 = "2500g or more"
;
 
/* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
1 = 'White'
2 = 'Black'
3 = 'Hispanic'
4 = 'Asian and NH/PI'
5 = 'Amer Indian/AN'
6 = 'Other'
;
 
/* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
value PAYCAT
1 = 'Medicare'
2 = 'Medicaid'
3 = 'Private'
4 = 'Self Pay'
5 = 'No Charge'
6 = 'Other'
;


* -------------------------------------------------------------- ;
* --- PSI17 DEFINING FORMATS ------------------------------------- ;
* -------------------------------------------------------------- ;

/* Diagnosis codeset BIRTHID last updated 160922 for IDC10 v60rev3 */
Value $BIRTHID
"P100" = "1" /* Subdural hemorrhage due to birth injury */
"P101" = "1" /* Cerebral hemorrhage due to birth injury */
"P102" = "1" /* Intraventricular hemorrhage due to birth injury */
"P103" = "1" /* Subarachnoid hemorrhage due to birth injury */
"P104" = "1" /* Tentorial tear due to birth injury */
"P108" = "1" /* Other intracranial lacerations and hemorrhages due to birth injury */
"P109" = "1" /* Unspecified intracranial laceration and hemorrhage due to birth injury */
"P110" = "1" /* Cerebral edema due to birth injury */
"P111" = "1" /* Other specified brain damage due to birth injury */
"P112" = "1" /* Unspecified brain damage due to birth injury */
"P113" = "1" /* Birth injury to facial nerve */
"P114" = "1" /* Birth injury to other cranial nerves */
"P115" = "1" /* Birth injury to spine and spinal cord */
"P119" = "1" /* Birth injury to central nervous system, unspecified */
"P122" = "1" /* Epicranial subaponeurotic hemorrhage due to birth injury */
"P130" = "1" /* Fracture of skull due to birth injury */
"P131" = "1" /* Other birth injuries to skull */
"P132" = "1" /* Birth injury to femur */
"P133" = "1" /* Birth injury to other long bones */
"P138" = "1" /* Birth injuries to other parts of skeleton */
"P139" = "1" /* Birth injury to skeleton, unspecified */
"P142" = "1" /* Phrenic nerve paralysis due to birth injury */
"P148" = "1" /* Birth injuries to other parts of peripheral nervous system */
"P149" = "1" /* Birth injury to peripheral nervous system, unspecified */
"P150" = "1" /* Birth injury to liver */
"P151" = "1" /* Birth injury to spleen */
"P152" = "1" /* Sternomastoid injury due to birth injury */
"P153" = "1" /* Birth injury to eye */
"P154" = "1" /* Birth injury to face */
"P155" = "1" /* Birth injury to external genitalia */
"P156" = "1" /* Subcutaneous fat necrosis due to birth injury */
"P158" = "1" /* Other specified birth injuries */
Other = "0"
;

/* Diagnosis codeset LIVEB2D last updated 160922 for IDC10 v60rev3 */
Value $LIVEB2D
"Z381" = "1" /* Single liveborn infant, born outside hospital */
"Z384" = "1" /* Twin liveborn infant, born outside hospital */
"Z387" = "1" /* Other multiple liveborn infant, born outside hospital */
Other = "0"
;

/* Diagnosis codeset LIVEBND last updated 160922 for IDC10 v60rev3 */
Value $LIVEBND
"Z3800" = "1" /* Single liveborn infant, delivered vaginally */
"Z3801" = "1" /* Single liveborn infant, delivered by cesarean */
"Z3830" = "1" /* Twin liveborn infant, delivered vaginally */
"Z3831" = "1" /* Twin liveborn infant, delivered by cesarean */
"Z3861" = "1" /* Triplet liveborn infant, delivered vaginally */
"Z3862" = "1" /* Triplet liveborn infant, delivered by cesarean */
"Z3863" = "1" /* Quadruplet liveborn infant, delivered vaginally */
"Z3864" = "1" /* Quadruplet liveborn infant, delivered by cesarean */
"Z3865" = "1" /* Quintuplet liveborn infant, delivered vaginally */
"Z3866" = "1" /* Quintuplet liveborn infant, delivered by cesarean */
"Z3868" = "1" /* Other multiple liveborn infant, delivered vaginally */
"Z3869" = "1" /* Other multiple liveborn infant, delivered by cesarean */
Other = "0"
;

/* Diagnosis codeset LW1000G last updated 160922 for IDC10 v60rev3 */
Value $LW1000G
"P0503" = "1" /* Newborn light for gestational age, 750-999 grams */
"P0513" = "1" /* Newborn small for gestational age, 750-999 grams */
"P0703" = "1" /* Extremely low birth weight newborn, 750-999 grams */
Other = "0"
;

/* Diagnosis codeset LW1250G last updated 160922 for IDC10 v60rev3 */
Value $LW1250G
"P0504" = "1" /* Newborn light for gestational age, 1000-1249 grams */
"P0514" = "1" /* Newborn small for gestational age, 1000-1249 grams */
"P0714" = "1" /* Other low birth weight newborn, 1000-1249 grams */
Other = "0"
;

/* Diagnosis codeset LW1500G last updated 160922 for IDC10 v60rev3 */
Value $LW1500G
"P0505" = "1" /* Newborn light for gestational age, 1250-1499 grams */
"P0515" = "1" /* Newborn small for gestational age, 1250-1499 grams */
"P0715" = "1" /* Other low birth weight newborn, 1250-1499 grams */
Other = "0"
;

/* Diagnosis codeset LW1750G last updated 160922 for IDC10 v60rev3 */
Value $LW1750G
"P0506" = "1" /* Newborn light for gestational age, 1500-1749 grams */
"P0516" = "1" /* Newborn small for gestational age, 1500-1749 grams */
"P0716" = "1" /* Other low birth weight newborn, 1500-1749 grams */
Other = "0"
;

/* Diagnosis codeset LW2000G last updated 160922 for IDC10 v60rev3 */
Value $LW2000G
"P0507" = "1" /* Newborn light for gestational age, 1750-1999 grams */
"P0517" = "1" /* Newborn small for gestational age, 1750-1999 grams */
"P0717" = "1" /* Other low birth weight newborn, 1750-1999 grams */
Other = "0"
;

/* Diagnosis codeset LW2500G last updated 160922 for IDC10 v60rev3 */
Value $LW2500G
"P0508" = "1" /* Newborn light for gestational age, 2000-2499 grams */
"P0518" = "1" /* Newborn small for gestational age, 2000-2499 grams */
"P0718" = "1" /* Other low birth weight newborn, 2000-2499 grams */
Other = "0"
;

/* Diagnosis codeset LW500G last updated 160922 for IDC10 v60rev3 */
Value $LW500G
"P0501" = "1" /* Newborn light for gestational age, less than 500 grams */
"P0511" = "1" /* Newborn small for gestational age, less than 500 grams */
"P0701" = "1" /* Extremely low birth weight newborn, less than 500 grams */
Other = "0"
;

/* Diagnosis codeset LW750G last updated 160922 for IDC10 v60rev3 */
Value $LW750G
"P0502" = "1" /* Newborn light for gestational age, 500-749 grams */
"P0512" = "1" /* Newborn small for gestational age, 500-749 grams */
"P0702" = "1" /* Extremely low birth weight newborn, 500-749 grams */
Other = "0"
;

/* Diagnosis codeset OSTEOID last updated 160922 for IDC10 v60rev3 */
Value $OSTEOID
"Q780" = "1" /* Osteogenesis imperfecta */
Other = "0"
;

/* Diagnosis codeset PRETEID last updated 160922 for IDC10 v60rev3 */
Value $PRETEID
"P0700" = "1" /* Extremely low birth weight newborn, unspecified weight */
"P0701" = "1" /* Extremely low birth weight newborn, less than 500 grams */
"P0702" = "1" /* Extremely low birth weight newborn, 500-749 grams */
"P0703" = "1" /* Extremely low birth weight newborn, 750-999 grams */
"P0710" = "1" /* Other low birth weight newborn, unspecified weight */
"P0714" = "1" /* Other low birth weight newborn, 1000-1249 grams */
"P0715" = "1" /* Other low birth weight newborn, 1250-1499 grams */
"P0716" = "1" /* Other low birth weight newborn, 1500-1749 grams */
"P0717" = "1" /* Other low birth weight newborn, 1750-1999 grams */
Other = "0"
;

Run;
